@@ -189,10 +189,8 @@ class IInclude(ABC):
 
   def update_link(self, text: str) -> str:
     logging.debug("update_link(%s)", text)
-    if "https" in text:
-      return text
     prefix = self.file.include_path.relative_to(self.file.repo.path)
-    text = re.sub(r"(\[.*\])\((.*)\)", rf'\1({prefix}/\2)', text.strip())
+    text = re.sub(r"[!](\[.*\])\((?!http)(.*)\)", rf'\1({prefix}/\2)', text.strip())
     return "".join(ch for i, ch in enumerate(text) if i <= 1 or not (text[i - 1] == text[i - 2] == ch == "\n")) + "\n"
 
 
@@ -277,7 +275,6 @@ class Link(IInclude):
   def to_markdown(self):
     logging.debug("to_markdown(%s)", self.path)
     repo = self.file.repo
-    assert self.path.is_file(), f"{self.path} is not a file"
     return f"[{self.path.name}]({repo.url}/{repo.deploy_branch}/{self.path.relative_to(repo.path)})\n"
 
 
